@@ -13,6 +13,7 @@ Player::Player(QWidget *parent) :
     reload = false;
     playing = false;
     audio = new Audio();
+    articleLoaded = false;
 
     connect(audio,SIGNAL(finished()), this, SLOT(playingFinished()));
     connect(audio, SIGNAL(wavCreated()), this, SLOT(wavCreated()));
@@ -65,6 +66,8 @@ void Player::openArticle(QString itemName, QString text)
 
     audio->createWav(path);
 
+    articleLoaded = true;
+
 }
 
 void Player::clearCurrentArticles()
@@ -86,7 +89,7 @@ void Player::linkListWidget_itemClicked(QListWidgetItem *item)
 
 void Player::on_backwardButton_clicked()
 {
-    if (this->ui->playListWidget->currentRow() >= 1 )
+    if (this->ui->playListWidget->currentRow() >= 1 && ui->playListWidget->count() != 0)
     {
         reload = true;
         this->ui->playListWidget->item(this->ui->playListWidget->currentRow())->setSelected(false);
@@ -98,7 +101,7 @@ void Player::on_backwardButton_clicked()
 
 void Player::on_forwardButton_clicked()
 {
-    if (this->ui->playListWidget->currentRow() < this->ui->playListWidget->count())
+    if (this->ui->playListWidget->currentRow() < this->ui->playListWidget->count() && ui->playListWidget->count() != 0)
     {
         reload = true;
         this->ui->playListWidget->item(this->ui->playListWidget->currentRow())->setSelected(false);
@@ -128,17 +131,20 @@ void Player::on_linksButton_clicked()
 
 void Player::on_playPauseButton_clicked()
 {
-   // system("espeak -f "+ path);
-
-    if (!playing)
+    if (articleLoaded)
     {
-        audio->play();
-        playing = true;
-    }
-    else
-    {
-        audio->pause();
-        playing = false;
+        if (!playing)
+        {
+            audio->play();
+            playing = true;
+            this->ui->playPauseButton->setIcon(QIcon(":/images/Icon_pause.png"));
+        }
+        else
+        {
+            audio->pause();
+            playing = false;
+            this->ui->playPauseButton->setIcon(QIcon(":/images/Icon_play.png"));
+        }
     }
 
 }
