@@ -10,11 +10,8 @@ Playlist::Playlist(QWidget *parent) :
     ui->setupUi(this);
     playlistlist = new Playlists();
     this->updateList();
-    ui->treeWidget->setColumnCount(2);
-    ui->treeWidget->setColumnWidth(0,300);
-
-
-
+    ui->treeWidget->setColumnCount(1);
+ //   ui->treeWidget->setColumnWidth(0,300);
 
 }
 
@@ -26,8 +23,8 @@ Playlist::~Playlist()
 void Playlist::on_treeWidget_itemClicked(QTreeWidgetItem *item, int column)
 {
 
-    if (column == 0)
-    {
+ //   if (column == 0)
+ //   {
         if (item->childCount() == 0)
             this->articleSelected(item, column);
 
@@ -35,8 +32,8 @@ void Playlist::on_treeWidget_itemClicked(QTreeWidgetItem *item, int column)
             this->playlistSelected(item->takeChildren(), column);
 
         this->hide();
-    }
-    if (column == 1)
+ //   }
+  /*  if (column == 1)
     {
         if (item->childCount() == 0)
             playlistlist->removePlaylistItem(item->data(1, 1).toString(), column, item->parent());
@@ -45,10 +42,21 @@ void Playlist::on_treeWidget_itemClicked(QTreeWidgetItem *item, int column)
             playlistlist->removePlaylist(item->text(column));
 
         this->updateList();
-    }
+    }*/
 
 }
 
+void Playlist::on_treeWidget_itemPressed(QTreeWidgetItem *item, int column)
+{
+    if (item->childCount() == 0)
+        playlistlist->removePlaylistItem(item->data(1, 1).toString(), column, item->parent());
+
+    else
+        playlistlist->removePlaylist(item->text(column));
+
+    this->updateList();
+}
+
 QStringList Playlist::getPlaylists()
 {
     return playlistlist->getPlaylistTitles();
@@ -64,34 +72,34 @@ void Playlist::updateList()
 {
     this->ui->treeWidget->clear();
     QList<QTreeWidgetItem *> items;
-    QList<QTreeWidgetItem *> removes;
+//    QList<QTreeWidgetItem *> removes;
     foreach(QString title, this->playlistlist->getPlaylistTitles())
     {
 
         QTreeWidgetItem *item = new QTreeWidgetItem(QStringList(title));
         QList<QTreeWidgetItem*> children;
 
-        QTreeWidgetItem *itemRemove = new QTreeWidgetItem(QStringList("Remove"));
-        itemRemove->setData(1, Qt::DisplayRole, QVariant(title));
-        QList<QTreeWidgetItem*> removeChildren;
+  //      QTreeWidgetItem *itemRemove = new QTreeWidgetItem(QStringList("Remove"));
+  //      itemRemove->setData(1, Qt::DisplayRole, QVariant(title));
+  //      QList<QTreeWidgetItem*> removeChildren;
 
         foreach (QString article, this->playlistlist->getPlaylistContent(title))
         {
             children.append(new QTreeWidgetItem(QStringList(article)));
 
-            QTreeWidgetItem *temp = new QTreeWidgetItem(QStringList("Remove"));
-            temp->setData(1,Qt::DisplayRole, QVariant(article));
-            removeChildren.append(temp);
+     //       QTreeWidgetItem *temp = new QTreeWidgetItem(QStringList("Remove"));
+     //       temp->setData(1,Qt::DisplayRole, QVariant(article));
+     //       removeChildren.append(temp);
 
         }
         item->addChildren(children);
-        itemRemove->addChildren(removeChildren);
+     //   itemRemove->addChildren(removeChildren);
         items.append(item);
-        removes.append(itemRemove);
+     //   removes.append(itemRemove);
        // item->set
         //this->ui->treeWidget->addTopLevelItem(item);
     }
     this->ui->treeWidget->insertTopLevelItems(0, items);
-    this->ui->treeWidget->insertTopLevelItems(1, removes);
+   // this->ui->treeWidget->insertTopLevelItems(0, removes);
 }
 
